==> cmsmadesimple-1.10.3-full.tar.gz: modules/MicroTiny/lang/ext/da_DK.php <==
<?php
$lang['friendlyname'] = 'MicroTiny WYSIWYG redigering';
$lang['help'] = '<strong>Hvad g&oslash;r dette modul?</strong>
<br/>
MicroTiny er en lille udgave af TinyMCE-redigeringssystemet, som tidligere var det der fulgte med som standard n&aring;r man installerede CMS Made Simple.
Det giver ikke mulighed for mere end de mest grundliggende redigerings metoder, men er stadig et kraftfuldt v&aelig;rkt&oslash;j til at &aelig;ndre indholdet af sider.
<br/><br/>
<strong>Hvad kan g&aring; galt?</strong>
<br/>
MicroTiny er baseret p&aring; JavaScript s&aring; der kr&aelig;ves en nyere browser. IE7+, og n&aelig;sten alle andre skulle dog v&aelig;re tilstr&aelig;kkeligt.
P&aring; nogen servere kan det v&aelig;re n&oslash;dvendigt at sl&aring; &#039;benyt statisk konfiguration&#039; til for at f&aring; det til at virke. Pr&oslash;v det hvis du blot ser et almindeligt redigeringsfelt uden redigeringsikoner. Men virker det uden dette sl&aring;et til er det bedre at lade det v&aelig;re sl&aring;et fra.';
$lang['example'] = 'MicroTiny eksempel';
$lang['settings'] = 'Indstillinger';
$lang['youareintext'] = 'Du er i';
$lang['dimensions'] = 'HxB';
$lang['size'] = 'Str.';
$lang['filepickertitle'] = 'Fil-v&aelig;lger';
$lang['cmsmslinker'] = 'CMSMS Link&#039;er';
$lang['tmpnotwritable'] = 'Konfigurationen kunne ikke skrives til tmp-mappen! Ret venligste dette!';
$lang['css_styles_text'] = 'CSS stilarter';
$lang['css_styles_help'] = 'CSS-stilnavne der st&aring;r her tilf&oslash;jes til en dropdown-boks i editoren. Hvis der ikke st&aring;r noget her vises dropdown-boksen ikke (standard).';
$lang['css_styles_help2'] = 'The styles can either be just the class name, or a classname with a new name to show.
Must be sepereated by either commas or newlines.
<br/>Example: mystyle1, My style name=mystyle
<br/>Result: a dropdown containing 2 entries, &#039;mystyle1&#039; and &#039;My stylename&#039; resulting in the insertion of mystyl1, and mystyle2 respectively.
<br/>Note: No checking for the actual existence of the stylenames are done. They are used blindly.';
$lang['usestaticconfig_text'] = 'Benyt statisk konfiguration';
$lang['usestaticconfig_help'] = 'Dette laver en statisk konfigurationsfil i stedet for den dynamiske. Dette virker bedre p&aring; nogen server (f.eks. p&aring; serverer der k&oslash;rer PHP som CGI)';
$lang['allowimages_text'] = 'Tillad billeder';
$lang['allowimages_help'] = 'Dette sl&aring;r en billedknap til p&aring; v&aelig;rkt&oslash;jslinie, der mulighed for at inds&aelig;tte et billede i indholdet';
$lang['settingssaved'] = 'Indstillingerne blev gemt';
$lang['savesettings'] = 'Gem indstillingerne';
$lang['utma'] = '156861353.2039886585.1231713618.1261530756.1262554946.86';
$lang['utmz'] = '156861353.1261485831.83.14.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['qca'] = '1229601790-85243197-43260713';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.11.10-full.tar.gz: modules/MicroTiny/lang/ext/da_DK.php <==
<?php
$lang['admindescription'] = 'En skr&aelig;llet, men alligevel st&aelig;rk implementering af TinyMCE WYSIWYG editoren.';
$lang['force_blackonwhite'] = 'S&oslash;rg for at teksten er sort p&aring; hvid baggrund';
$lang['help_force_blackonwhite'] = 'Tvinger MicroTiny editoren til at vise sort tekst p&aring; hvid baggrund  Dette kan v&aelig;re en hj&aelig;lp, n&aring;r der skal vises tekst i wysiwyg editoren i et milj&oslash; med m&oslash;rke baggrunde og lyse forgrunde.';
$lang['strip_background'] = 'Fjern baggrundseffekter lavet af CSS';
$lang['help_strip_background'] = 'Fjern baggrundseffekter, som kommer fra typografiark.  Dette kan v&aelig;re en hj&aelig;lp, n&aring;r der skal vises tekst i wysiwyg editoren i et milj&oslash; med m&oslash;rke baggrunde og lyse forgrunde.';
$lang['show_statusbar'] = 'Vis statuslinjen';
$lang['help_show_statusbar'] = 'Aktiv&eacute;r en statuslinje i bunden af wysiwyg-omr&aring;det.  Denne indstilling er kun relevant i admin-visning.';
$lang['allow_resize'] = 'Tillad gendannelse af st&oslash;rrelse';
$lang['help_allow_resize'] = 'Tillad gendannelse af st&oslash;rrelsen p&aring; wysiwyg-omr&aring;det.  Foruds&aelig;tter at statuslinjen er aktiveret.';
$lang['view_html'] = 'Vis HTML';
$lang['friendlyname'] = 'MicroTiny WYSIWYG redigering';
$lang['help'] = '<strong>Hvad g&oslash;r dette modul?</strong>
<br/>
MicroTiny er en lille udgave af TinyMCE-redigeringssystemet, som tidligere var det der fulgte med som standard n&aring;r man installerede CMS Made Simple.
Det giver ikke mulighed for mere end de mest grundliggende redigerings metoder, men er stadig et kraftfuldt v&aelig;rkt&oslash;j til at &aelig;ndre indholdet af sider.
<br/><br/>
<strong>Hvad kan g&aring; galt?</strong>
<br/>
MicroTiny er baseret p&aring; JavaScript s&aring; der kr&aelig;ves en nyere browser. IE7+, og n&aelig;sten alle andre skulle dog v&aelig;re tilstr&aelig;kkeligt.
P&aring; nogen servere kan det v&aelig;re n&oslash;dvendigt at sl&aring; &#039;benyt statisk konfiguration&#039; til for at f&aring; det til at virke. Pr&oslash;v det hvis du blot ser et almindeligt redigeringsfelt uden redigeringsikoner. Men virker det uden dette sl&aring;et til er det bedre at lade det v&aelig;re sl&aring;et fra.';
$lang['example'] = 'MicroTiny eksempel';
$lang['settings'] = 'Indstillinger';
$lang['youareintext'] = 'Du er i';
$lang['dimensions'] = 'HxB';
$lang['size'] = 'Str.';
$lang['filepickertitle'] = 'Fil-v&aelig;lger';
$lang['cmsmslinker'] = 'CMSMS Link&#039;er';
$lang['tmpnotwritable'] = 'Konfigurationen kunne ikke skrives til tmp-mappen! Ret venligste dette!';
$lang['css_styles_text'] = 'CSS stilarter';
$lang['css_styles_help'] = 'CSS-stilnavne der st&aring;r her tilf&oslash;jes til en dropdown-boks i editoren. Hvis der ikke st&aring;r noget her vises dropdown-boksen ikke (standard).';
$lang['css_styles_help2'] = 'The styles can either be just the class name, or a classname with a new name to show.
Must be sepereated by either commas or newlines.
<br/>Example: mystyle1, My style name=mystyle
<br/>Result: a dropdown containing 2 entries, &#039;mystyle1&#039; and &#039;My stylename&#039; resulting in the insertion of mystyl1, and mystyle2 respectively.
<br/>Note: No checking for the actual existence of the stylenames are done. They are used blindly.';
$lang['usestaticconfig_text'] = 'Benyt statisk konfiguration';
$lang['usestaticconfig_help'] = 'Dette laver en statisk konfigurationsfil i stedet for den dynamiske. Dette virker bedre p&aring; nogen server (f.eks. p&aring; serverer der k&oslash;rer PHP som CGI)';
$lang['allowimages_text'] = 'Tillad billeder';
$lang['allowimages_help'] = 'Dette sl&aring;r en billedknap til p&aring; v&aelig;rkt&oslash;jslinjen, der g&oslash;r det muligt at inds&aelig;tte et billede i indholdet';
$lang['settingssaved'] = 'Indstillingerne blev gemt';
$lang['savesettings'] = 'Gem indstillingerne';
$lang['utma'] = '156861353.1669182101.1357277528.1357300362.1357303144.6';
$lang['utmz'] = '156861353.1357277528.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/ucp.php|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
